datastructuretools.SortedCollection
===================================

.. autoclass:: abjad.tools.datastructuretools.SortedCollection.SortedCollection

Lineage
-------

.. graphviz::

   digraph InheritanceGraph {
       graph [background=transparent,
           color=lightslategrey,
           fontname=Arial,
           outputorder=edgesfirst,
           overlap=prism,
           penwidth=2,
           rankdir=LR,
           root="__builtin__.object",
           splines=spline,
           style="dotted, rounded"];
       node [colorscheme=pastel19,
           fontname=Arial,
           fontsize=12,
           penwidth=2,
           style="filled, rounded"];
       edge [color=lightsteelblue2,
           penwidth=2];
       subgraph cluster___builtin__ {
           graph [label=__builtin__];
           "__builtin__.object" [color=1,
               group=0,
               label=object,
               shape=box];
       }
       subgraph cluster_datastructuretools {
           graph [label=datastructuretools];
           "datastructuretools.SortedCollection" [color=black,
               fontcolor=white,
               group=1,
               label=<<B>SortedCollection</B>>,
               shape=box,
               style="filled, rounded"];
       }
       "__builtin__.object" -> "datastructuretools.SortedCollection";
   }

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.clear
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.copy
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.count
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.find
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.find_ge
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.find_gt
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.find_le
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.find_lt
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.index
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.insert
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.insert_right
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.key
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.remove
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.__contains__
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.__getitem__
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.__iter__
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.__len__
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.__repr__
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection.__reversed__

Bases
-----

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.key
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.clear
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.copy
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.count
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.find
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.find_ge
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.find_gt
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.find_le
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.find_lt
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.index
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.insert
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.insert_right
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.remove
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.__getitem__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.SortedCollection.SortedCollection.__reversed__
   :noindex:
